@@ -1,4 +1,4 @@
 BB_Prior_prob_phi <-
 function(phi){
-		dexp(1/phi,rate=5,log=TRUE)
+		stats::dexp(1/phi,rate=5,log=TRUE)
 	}
