@@ -1,4 +1,4 @@
 Prior_prob_alpha0 <-
 function(a0){
-		log(dgamma(a0,1,1))
+		log(stats::dgamma(a0,1,1))
 	}
