@@ -1,4 +1,4 @@
 Prior_prob_alphaD <-
 function(aD){
-		dexp(aD,log=TRUE)
+		stats::dexp(aD,log=TRUE)
 	}
