@@ -5,15 +5,15 @@ function(accepted.moves,proposed.moves,param.name=deparse(substitute(accepted.mo
 		acceptance.rate <- accepted.moves[x]/proposed.moves[x]
 			plot(acceptance.rate,
 				pch=20,
-				col=adjustcolor(1,alpha.f=0.7),
+				col=grDevices::adjustcolor(1,alpha.f=0.7),
 				xlab="MCMC sampled generations",
 				ylab="acceptance rate",
 				main=paste(param.name,"acceptance rate",sep=" "),
 				ylim=c(0,1))
-			abline(h=c(0.2,0.7),col="green",lty="dashed",lwd=2)
+			graphics::abline(h=c(0.2,0.7),col="green",lty="dashed",lwd=2)
 			
-			if(median(acceptance.rate) > 0.7 || median(acceptance.rate) < 0.2){
-				polygon(x=c(0-0.04*length(acceptance.rate),
+			if(stats::median(acceptance.rate) > 0.7 || stats::median(acceptance.rate) < 0.2){
+				graphics::polygon(x=c(0-0.04*length(acceptance.rate),
 							0-0.04*length(acceptance.rate),
 							length(acceptance.rate)+0.04*length(acceptance.rate),
 							length(acceptance.rate)+0.04*length(acceptance.rate)),
@@ -21,6 +21,6 @@ function(accepted.moves,proposed.moves,param.name=deparse(substitute(accepted.mo
 						1+0.04*length(acceptance.rate),
 						1+0.04*length(acceptance.rate),
 						0-0.04*length(acceptance.rate)),
-						col=adjustcolor("red",alpha.f=0.2))
+						col=grDevices::adjustcolor("red",alpha.f=0.2))
 			}
 	}
