@@ -7,22 +7,22 @@ function(phi,percent.burnin=0,thinning=1,population.names=NULL,pop.index=NULL){
 				plot(Fk,
 					pch=19,
 					ylim=c(0,1),
-					col=adjustcolor(1,alpha.f=0.4),
+					col=grDevices::adjustcolor(1,alpha.f=0.4),
 					main=sprintf("Trace Plot of F parameter, population %s",pop.index),
 					xlab="MCMC sampled generations",
 					ylab=sprintf("F parameter, population %s",pop.index)
                 )
-                abline(h=median(Fk),col="red")	
+                graphics::abline(h=stats::median(Fk),col="red")	
 			}
 				if(!is.null(population.names)){
 				plot(Fk,
 					pch=19,
 					ylim=c(0,1),
-					col=adjustcolor(1,alpha.f=0.4),
+					col=grDevices::adjustcolor(1,alpha.f=0.4),
 					main=paste("Trace Plot of F parameter,",population.names,sep=" "),
 					xlab="MCMC sampled generations",
 					ylab=paste("F parameter,",population.names,sep=" ")
                 )
-                abline(h=median(Fk),col="red")	
+                graphics::abline(h=stats::median(Fk),col="red")	
 			}
 	}
